%define		qtver 5.15.16

Summary:	A professional CAD system
Name:		qcad
Version:	3.32.1.0
Release:	%mkrel 1
Group:		Graphics/Editors and Converters
License:	GPLv3 with exceptions or CC-BY or GPLv2+ or LGPLv2+ or BSD
URL:		https://www.qcad.org/
Source0:	https://github.com/qcad/qcad/archive/v%{version}/%{name}-%{version}.tar.gz

# minimal BuildRequires
BuildRequires:	cmake(Qt5Concurrent)
BuildRequires:	cmake(Qt5Core) >= %{qtver}
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5OpenGL)
BuildRequires:	cmake(Qt5PrintSupport)
BuildRequires:	cmake(Qt5Qml)
BuildRequires:	cmake(Qt5Script)
BuildRequires:	cmake(Qt5ScriptTools)
BuildRequires:	cmake(Qt5Sql)
BuildRequires:	cmake(Qt5Svg)
BuildRequires:	cmake(Qt5Xml)
BuildRequires:	cmake(Qt5XmlPatterns)
BuildRequires:	cmake(Qt5LinguistTools)
BuildRequires:	cmake(Qt5UiTools)
BuildRequires:	cmake(Qt5Designer)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	spatialindex-devel

Requires:	qtimageformats5
Requires:	qttranslations5

Provides:	bundled(qtscriptgenerator)

%description
QCad is a professional CAD System. With QCad you can easily construct
and change drawings with ISO-text and many other features and save
them as DXF-files. These DXF-files are the interface to many
CAD-systems such as AutoCAD(TM) and many others.

%prep
%autosetup -p1

# Workaround for unused SPECPARTS directory
rm -rf ../*-SPECPARTS

rm -rf src/3rdparty/spatialindexnavel/include/spatialindex

cp -a src/3rdparty/qt-labs-qtscriptgenerator-5.15.8 src/3rdparty/qt-labs-qtscriptgenerator-5.15.16
mv src/3rdparty/qt-labs-qtscriptgenerator-5.15.16/qt-labs-qtscriptgenerator-5.15.8.pro \
src/3rdparty/qt-labs-qtscriptgenerator-5.15.16/qt-labs-qtscriptgenerator-5.15.16.pro

%build
%qmake_qt5

%make_build

%install
install -dm755 %{buildroot}%{_datadir}/%{name}
cp -r examples fonts libraries linetypes patterns plugins scripts ts %{buildroot}%{_datadir}/%{name}
cp release/* %{buildroot}%{_datadir}/%{name}

# qt
for sofiles in %{_qt5_plugindir}/imageformats/*.so
do
    ln -sf ${sofiles} %{buildroot}%{_datadir}/%{name}/plugins/imageformats/${sofiles##/*/}
done

for sofiles in %{_qt5_plugindir}/sqldrivers/*.so
do
    ln -sf ${sofiles} %{buildroot}%{_datadir}/%{name}/plugins/sqldrivers/${sofiles##/*/}
done

for sofiles in %{_qt5_plugindir}/printsupport/*.so
do
    ln -sf ${sofiles} %{buildroot}%{_datadir}/%{name}/plugins/printsupport/${sofiles##/*/}
done

install -Dm644 scripts/%{name}_icon.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}_icon.png
install -Dm644 scripts/%{name}_icon.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}_icon.svg

install -dm0755 %{buildroot}%{_bindir}
echo -e '#!/bin/sh\ncd %{_datadir}/%{name}\nLD_LIBRARY_PATH=`pwd`:%{_libdir}/%{name}:$LD_LIBRARY_PATH exec ./%{name}-bin' > %{buildroot}%{_bindir}/%{name}
chmod 0755 %{buildroot}%{_bindir}/%{name}

rm -f %{buildroot}%{_datadir}/%{name}/*.a

install -dm0755 %{buildroot}%{_libdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/*.so %{buildroot}%{_libdir}/%{name}

# man page
install -Dm644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

# documentation for help system
install -Dm644 readme.txt %{buildroot}%{_datadir}/%{name}/readme.txt

# desktop
install -Dm644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

# remove project files
find %{buildroot} \( -name '*.pri' -or -name '*.pro' -or -name '*.ts' \) -delete
find %{buildroot} \( -name 'Makefile*' -or -name '.gitignore' \) -delete

%files
%doc readme.txt README.md
%license LICENSE.txt gpl-3.0.txt cc-by-3.0.txt gpl-3.0-exceptions.txt
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%{_iconsdir}/hicolor/*/apps/%{name}_icon.png
%{_iconsdir}/hicolor/scalable/apps/*.svg
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_mandir}/man1/%{name}.1.*


%changelog
* Fri Feb 14 2025 daviddavid <daviddavid> 3.32.1.0-1.mga10
+ Revision: 2148853
- new version: 3.32.1.0

* Sun Oct 27 2024 kekepower <kekepower> 3.31.2.0-2.mga10
+ Revision: 2111539
- Reupload source tar ball

* Fri Oct 25 2024 kekepower <kekepower> 3.31.2.0-1.mga10
+ Revision: 2111123
- Update to version 3.31.2.0

* Sat Sep 28 2024 kekepower <kekepower> 3.31.1.2-1.mga10
+ Revision: 2101685
- Update to version 3.31.1.2

* Sat Sep 21 2024 kekepower <kekepower> 3.31.1.0-1.mga10
+ Revision: 2099845
- Update to version 3.31.1.0

* Wed Jul 31 2024 kekepower <kekepower> 3.30.1.3-1.mga10
+ Revision: 2083063
- Update to version 3.30.1.3

* Tue May 07 2024 daviddavid <daviddavid> 3.29.6.4-1.mga10
+ Revision: 2062681
- new version: 3.29.6.4

* Mon May 06 2024 daviddavid <daviddavid> 3.29.6.2-2.mga10
+ Revision: 2062550
- switch back to Qt5, Qt6 seems to not work for now (mga#33182)

* Sat Apr 20 2024 kekepower <kekepower> 3.29.6.2-1.mga10
+ Revision: 2059985
- Update to version 3.29.6.2

* Wed Sep 06 2023 kekepower <kekepower> 3.28.2.2-1.mga10
+ Revision: 1984798
- Update to version 3.28.2.2

* Tue Aug 29 2023 kekepower <kekepower> 3.28.1.3-1.mga10
+ Revision: 1981044
- Update to version 3.28.1.3

* Sat Apr 01 2023 kekepower <kekepower> 3.28.1.0-1.mga9
+ Revision: 1951148
- Update to version 3.28.1.0

* Tue Mar 28 2023 kekepower <kekepower> 3.28.0.0-1.mga9
+ Revision: 1950544
- Update to version 3.28.0.0

* Wed Feb 22 2023 kekepower <kekepower> 3.27.9.2-1.mga9
+ Revision: 1944758
- Update to version 3.27.9.2

* Mon Jan 16 2023 kekepower <kekepower> 3.27.9.0-1.mga9
+ Revision: 1933819
- Update to version 3.27.9.0

* Tue Dec 20 2022 kekepower <kekepower> 3.27.8.7-1.mga9
+ Revision: 1925423
- Update to version 3.27.8.7

* Fri Dec 16 2022 kekepower <kekepower> 3.27.8.6-1.mga9
+ Revision: 1923780
- Update to version 3.27.8.6

* Wed Nov 09 2022 kekepower <kekepower> 3.27.8.4-1.mga9
+ Revision: 1904840
- Update to version 3.27.8.4

* Wed Nov 02 2022 kekepower <kekepower> 3.27.8.3-1.mga9
+ Revision: 1901468
- Update to version 3.27.8.3

* Thu Oct 27 2022 kekepower <kekepower> 3.27.8.1-1.mga9
+ Revision: 1899729
- Update to version 3.27.8.1

* Fri Oct 07 2022 kekepower <kekepower> 3.27.8.0-1.mga9
+ Revision: 1895305
- Update to version 3.27.8.0

* Wed Oct 05 2022 kekepower <kekepower> 3.27.7.0-1.mga9
+ Revision: 1894916
- Update to version 3.27.7.0

* Wed Sep 28 2022 kekepower <kekepower> 3.27.6.11-1.mga9
+ Revision: 1892882
- Update to version 3.27.6.11

* Sun Sep 25 2022 kekepower <kekepower> 3.27.6.10-1.mga9
+ Revision: 1892188
- Update to version 3.27.6.10

* Fri Jul 08 2022 kekepower <kekepower> 3.27.6.7-1.mga9
+ Revision: 1868025
- Update to version 3.27.6.7

* Tue May 31 2022 kekepower <kekepower> 3.27.6.3-1.mga9
+ Revision: 1860886
- Update to version 3.27.6.3

* Wed May 18 2022 kekepower <kekepower> 3.27.6.0-1.mga9
+ Revision: 1858587
- Update to version 3.27.6.0

* Mon May 09 2022 kekepower <kekepower> 3.27.5.0-1.mga9
+ Revision: 1857238
- Update to version 3.27.5.0

* Fri May 06 2022 kekepower <kekepower> 3.27.4.0-1.mga9
+ Revision: 1856537
- Update to version 3.27.4.0

* Fri Apr 29 2022 kekepower <kekepower> 3.27.3.0-1.mga9
+ Revision: 1855010
- Update to version 3.27.3.0

* Wed Apr 27 2022 kekepower <kekepower> 3.27.2.0-1.mga9
+ Revision: 1854539
- Update to version 3.27.2.0

* Mon Mar 28 2022 kekepower <kekepower> 3.27.1.8-1.mga9
+ Revision: 1829850
- Update to version 3.27.1.8

* Thu Jan 27 2022 kekepower <kekepower> 3.27.1.6-1.mga9
+ Revision: 1769965
- Update to version 3.27.1.6

* Wed Jan 19 2022 kekepower <kekepower> 3.27.1.3-1.mga9
+ Revision: 1769076
- Update to version 3.27.1.3

* Mon Dec 13 2021 kekepower <kekepower> 3.27.1.0-1.mga9
+ Revision: 1761976
- Update to version 3.27.1.0

* Fri Dec 10 2021 kekepower <kekepower> 3.27.0.3-1.mga9
+ Revision: 1761280
- Update to version 3.27.0.3

* Tue Dec 07 2021 kekepower <kekepower> 3.27.0.2-1.mga9
+ Revision: 1761048
- Update to version 3.27.0.2

* Thu Dec 02 2021 kekepower <kekepower> 3.27.0.1-1.mga9
+ Revision: 1760542
- Update to version 3.27.0.1

* Thu Oct 28 2021 kekepower <kekepower> 3.27.0.0-1.mga9
+ Revision: 1753005
- Update to version 3.27.0.0

* Thu Oct 14 2021 kekepower <kekepower> 3.26.4.10-1.mga9
+ Revision: 1751464
- Update to version 3.26.4.10

* Mon Oct 11 2021 kekepower <kekepower> 3.26.4.9-1.mga9
+ Revision: 1750560
- Update to version 3.26.4.9

* Mon Sep 20 2021 kekepower <kekepower> 3.26.4.8-1.mga9
+ Revision: 1746095
- Update to version 3.26.4.8

* Sun Sep 19 2021 kekepower <kekepower> 3.26.4.7-1.mga9
+ Revision: 1745901
- Update to version 3.26.4.7

* Mon Aug 23 2021 kekepower <kekepower> 3.26.4.6-1.mga9
+ Revision: 1742436
- Update to version 3.26.4.6

* Fri Jul 23 2021 kekepower <kekepower> 3.26.4.5-1.mga9
+ Revision: 1737483
- Update to version 3.26.4.5

* Tue Jun 15 2021 kekepower <kekepower> 3.26.4.2-1.mga9
+ Revision: 1730862
- Update to version 3.26.4.2

* Mon May 31 2021 kekepower <kekepower> 3.26.3.0-1.mga9
+ Revision: 1728967
- Update to version 3.26.3.0

* Mon Apr 19 2021 kekepower <kekepower> 3.26.2.0-1.mga9
+ Revision: 1717022
- Update to version 3.26.2.0

* Mon Mar 08 2021 kekepower <kekepower> 3.26.1.0-1.mga9
+ Revision: 1700616
- Update to version 3.26.1.0

* Wed Mar 03 2021 kekepower <kekepower> 3.26.0.1-1.mga9
+ Revision: 1697272
- Update to version 3.26.0.1

* Thu Feb 25 2021 kekepower <kekepower> 3.25.2.13-1.mga9
+ Revision: 1690899
- Update to version 3.25.2.13

* Wed Dec 30 2020 kekepower <kekepower> 3.25.2.8-1.mga8
+ Revision: 1665587
- Update to version 3.25.2.8

* Fri Dec 18 2020 kekepower <kekepower> 3.25.2.7-1.mga8
+ Revision: 1660861
- Update to version 3.25.2.7

* Thu Dec 17 2020 umeabot <umeabot> 3.25.2.4-2.mga8
+ Revision: 1659568
- Rebuild for new Qt5

* Wed Nov 18 2020 kekepower <kekepower> 3.25.2.4-1.mga8
+ Revision: 1647109
- Update to version 3.25.2.4

* Tue Nov 03 2020 kekepower <kekepower> 3.25.2.3-1.mga8
+ Revision: 1642406
- Update to version 3.25.2.3

* Wed Oct 28 2020 kekepower <kekepower> 3.25.2.2-1.mga8
+ Revision: 1640031
- Update to version 3.25.2.2

* Mon Oct 19 2020 kekepower <kekepower> 3.25.2.1-1.mga8
+ Revision: 1637161
- Update to version 3.25.2.1

* Wed Sep 09 2020 kekepower <kekepower> 3.25.2.0-1.mga8
+ Revision: 1623791
- Update to version 3.25.2.0

* Mon Aug 31 2020 kekepower <kekepower> 3.25.1.0-1.mga8
+ Revision: 1620519
- Update to version 3.25.1.0
- Update to version 3.24.3.10

* Wed Jun 03 2020 kekepower <kekepower> 3.24.3.8-1.mga8
+ Revision: 1590150
- Update to version 3.24.3.8

* Thu May 28 2020 kekepower <kekepower> 3.24.3.7-1.mga8
+ Revision: 1588672
- Update to version 3.24.3.7

* Thu May 21 2020 kekepower <kekepower> 3.24.3.6-1.mga8
+ Revision: 1586598
- Update to version 3.24.3.6

* Tue Apr 28 2020 kekepower <kekepower> 3.24.3.4-1.mga8
+ Revision: 1573011
- Update to version 3.24.3.4

* Fri Apr 17 2020 kekepower <kekepower> 3.24.3.3-1.mga8
+ Revision: 1568254
- Update to version 3.24.3.3

* Fri Apr 17 2020 kekepower <kekepower> 3.24.3.2-1.mga8
+ Revision: 1567936
- Update to version 3.24.3.2

* Wed Apr 08 2020 kekepower <kekepower> 3.24.3.0-3.mga8
+ Revision: 1565631
- Add upstream commit to add Qt 5.14.1, 5.14.2 script bindings

* Wed Mar 18 2020 kekepower <kekepower> 3.24.3.0-1.mga8
+ Revision: 1557673
- Update to version 3.24.3.0

* Thu Mar 05 2020 kekepower <kekepower> 3.24.2.6-1.mga8
+ Revision: 1554028
- Disable Patch0 qcad-3.19.2.2-use-system-spatialindex.patch
- Update to version 3.24.2.6
- Use bundled version of spatialindex
+ daviddavid <daviddavid>
- QCAD does not depend on Quazip / WebKit / WebEngine anymore
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Oct 22 2019 kekepower <kekepower> 3.23.0.4-1.mga8
+ Revision: 1455145
- Update to version 3.23.0.4

* Mon Oct 07 2019 kekepower <kekepower> 3.23.0.3-1.mga8
+ Revision: 1450190
- Update to version 3.23.0.3

* Wed Sep 18 2019 kekepower <kekepower> 3.23.0.2-1.mga8
+ Revision: 1443478
- Update to version 3.23.0.2

* Mon Jul 29 2019 kekepower <kekepower> 3.23.0.0-1.mga8
+ Revision: 1425117
- Update to version 3.23.0.0

* Sun Jul 14 2019 kekepower <kekepower> 3.22.1.6-1.mga8
+ Revision: 1421427
- Update to version 3.22.1.6

* Sat Jun 29 2019 kekepower <kekepower> 3.22.1.3-1.mga8
+ Revision: 1415887
- Update to version 3.22.1.3

* Thu May 16 2019 kekepower <kekepower> 3.22.0.12-1.mga7
+ Revision: 1398092
- Update to version 3.22.0.12

* Mon Apr 15 2019 kekepower <kekepower> 3.22.0.7-1.mga7
+ Revision: 1390713
- Update to version 3.22.0.7

* Thu Apr 04 2019 kekepower <kekepower> 3.22.0.6-1.mga7
+ Revision: 1385712
- Update to version 3.22.0.6

* Mon Apr 01 2019 umeabot <umeabot> 3.22.0.5-2.mga7
+ Revision: 1384147
- Qt5 Rebuild

* Mon Mar 25 2019 kekepower <kekepower> 3.22.0.5-1.mga7
+ Revision: 1380133
- Add patch to support qt5.12.2
- Update to version 3.22.0.5

* Thu Mar 21 2019 kekepower <kekepower> 3.22.0.4-1.mga7
+ Revision: 1379477
- Update to version 3.22.0.4

* Mon Mar 18 2019 kekepower <kekepower> 3.22.0.3-1.mga7
+ Revision: 1378633
- Update to version 3.22.0.3

* Sat Mar 09 2019 kekepower <kekepower> 3.22.0.2-1.mga7
+ Revision: 1373235
- Update to version 3.22.0.2

* Wed Mar 06 2019 kekepower <kekepower> 3.22.0.1-1.mga7
+ Revision: 1371890
- Update to version 3.22.0.1
- Update to version 3.22.0.0
- Rediffed Patch0

* Mon Feb 25 2019 kekepower <kekepower> 3.21.3.19-1.mga7
+ Revision: 1370060
- Update to version 3.21.3.19

* Mon Feb 18 2019 kekepower <kekepower> 3.21.3.18-1.mga7
+ Revision: 1368256
- Update to version 3.21.3.18

* Thu Feb 14 2019 kekepower <kekepower> 3.21.3.17-1.mga7
+ Revision: 1367097
- Update to version 3.21.3.17

* Mon Feb 11 2019 neoclust <neoclust> 3.21.3.16-1.mga7
+ Revision: 1365269
- Add Qt 5.12.1 support
+ kekepower <kekepower>
- Update to version 3.21.3.16

* Wed Jan 30 2019 kekepower <kekepower> 3.21.3.15-3.mga7
+ Revision: 1361904
+ rebuild (emptylog)

* Mon Jan 28 2019 kekepower <kekepower> 3.21.3.15-2.mga7
+ Revision: 1361591
+ rebuild (emptylog)

* Fri Jan 25 2019 kekepower <kekepower> 3.21.3.15-1.mga7
+ Revision: 1360654
- Update to version 3.21.3.15
- Upstream reversed their version, hence 3.21 now

* Thu Jan 17 2019 kekepower <kekepower> 3.22.0.0-1.mga7
+ Revision: 1357672
- Update to version 3.22.0.0

* Tue Dec 18 2018 kekepower <kekepower> 3.21.3.14-1.mga7
+ Revision: 1342616
- Update to version 3.21.3.14

* Thu Dec 13 2018 kekepower <kekepower> 3.21.3.12-1.mga7
+ Revision: 1341019
- Update to version 3.21.3.12

* Sun Dec 09 2018 kekepower <kekepower> 3.21.3.11-1.mga7
+ Revision: 1339354
- Update to version 3.21.3.11

* Tue Nov 27 2018 kekepower <kekepower> 3.21.3.10-1.mga7
+ Revision: 1335948
- Update to version 3.21.3.10

* Thu Nov 22 2018 kekepower <kekepower> 3.21.3.9-1.mga7
+ Revision: 1333335
- Update to version 3.21.3.9

* Wed Nov 21 2018 kekepower <kekepower> 3.21.3.8-1.mga7
+ Revision: 1333081
- Update to version 3.21.3.8

* Thu Oct 04 2018 kekepower <kekepower> 3.21.3.2-1.mga7
+ Revision: 1317369
- Update to version 3.21.3.2

* Tue Sep 25 2018 kekepower <kekepower> 3.21.3.1-1.mga7
+ Revision: 1304861
- Update to version 3.21.3.1

* Tue Sep 18 2018 kekepower <kekepower> 3.21.3.0-1.mga7
+ Revision: 1259945
- Update to version 3.21.3.0

* Mon Sep 10 2018 kekepower <kekepower> 3.21.2.9-1.mga7
+ Revision: 1258256
- Update to version 3.21.2.9

* Fri Sep 07 2018 kekepower <kekepower> 3.21.2.8-1.mga7
+ Revision: 1257716
- Update to version 3.21.2.8

* Thu Sep 06 2018 kekepower <kekepower> 3.21.2.7-1.mga7
+ Revision: 1257592
- Update to version 3.21.2.7

* Fri Aug 24 2018 kekepower <kekepower> 3.21.2.6-1.mga7
+ Revision: 1253773
- Update to version 3.21.2.6

* Tue Aug 21 2018 kekepower <kekepower> 3.21.2.5-1.mga7
+ Revision: 1253326
- Update to version 3.21.2.5

* Thu Aug 09 2018 kekepower <kekepower> 3.21.2.3-1.mga7
+ Revision: 1250838
- Update to version 3.21.2.3

* Fri Jul 20 2018 daviddavid <daviddavid> 3.21.2.2-1.mga7
+ Revision: 1244405
- new version: 3.21.2.2

* Fri Jun 22 2018 kekepower <kekepower> 3.21.0.0-1.mga7
+ Revision: 1238876
- Update to version 3.21.0.0

* Tue Jun 19 2018 kekepower <kekepower> 3.20.1.7-1.mga7
+ Revision: 1238227
- Update to version 3.20.1.7

* Thu Jun 14 2018 kekepower <kekepower> 3.20.1.6-1.mga7
+ Revision: 1236896
- Update to version 3.20.1.6

* Sat May 05 2018 kekepower <kekepower> 3.20.1.3-1.mga7
+ Revision: 1226240
- Update to version 3.20.1.3
- Fix Licenses

* Thu Apr 19 2018 kekepower <kekepower> 3.20.1.2-1.mga7
+ Revision: 1220071
- Update to version 3.20.1.2

* Tue Mar 13 2018 daviddavid <daviddavid> 3.19.2.3-1.mga7
+ Revision: 1209024
- new version: 3.19.2.3

* Sat Jan 13 2018 daviddavid <daviddavid> 3.19.2.2-1.mga7
+ Revision: 1192657
- new version: 3.19.2.2
- rename and rediff use-system-quazip-and-spatialindex patch
- fix build with Qt 5.9.3

* Fri Oct 06 2017 daviddavid <daviddavid> 3.18.1.0-1.mga7
+ Revision: 1169301
- new version: 3.18.1.0

* Fri Aug 11 2017 daviddavid <daviddavid> 3.17.3.6-1.mga7
+ Revision: 1139834
- new version: 3.17.3.6
- use system spatialindex
- package a svg icon

* Thu Nov 10 2016 daviddavid <daviddavid> 3.14.2.0-4.mga6
+ Revision: 1066282
- fix build now against Qt 5.6.2

* Mon Sep 05 2016 daviddavid <daviddavid> 3.14.2.0-3.mga6
+ Revision: 1050129
- do not build on armv5tl because of missing qtwebengine5

* Fri Jul 08 2016 daviddavid <daviddavid> 3.14.2.0-2.mga6
+ Revision: 1039802
- fix build against Qt 5.6.1
- add patch to use system quazip

* Thu Apr 28 2016 daviddavid <daviddavid> 3.14.2.0-1.mga6
+ Revision: 1007214
- new version: 3.14.2.0
- switch from qtwebkit to qtwebengine
- split out all BRs Qt5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 02 2015 alexl <alexl> 3.12.3.3-1.mga6
+ Revision: 907767
- version 3.12.3.3
- del upstreamed i18n.patch
- use desktop file from upstream

* Sun Nov 22 2015 alexl <alexl> 3.12.2.3-2.mga6
+ Revision: 904809
- less list of requires and buildrequires

* Sat Nov 21 2015 alexl <alexl> 3.12.2.3-1.mga6
+ Revision: 904718
- version 3.12.2.3
- build with qt5
- partially fix i18n for the first start
- del upstreamed patches
- install documentation for help system
- install man page
- fix removing project files
- install libs in libdir/qcad instead of libdir

* Tue Oct 20 2015 danf <danf> 3.6.2.0-6.mga6
+ Revision: 892921
- Fix the build against Qt 4.8.7

* Wed Jan 07 2015 alexl <alexl> 3.6.2.0-5.mga5
+ Revision: 808985
- added GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 3.6.2.0-4.mga5
+ Revision: 739744
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.6.2.0-3.mga5
+ Revision: 688469
- Mageia 5 Mass Rebuild
+ danf <danf>
- Added bzero.patch to fix compiling with glibc 2.20

* Thu Aug 14 2014 alexl <alexl> 3.6.2.0-2.mga5
+ Revision: 662542
- translated desktop file

* Mon Jul 21 2014 alexl <alexl> 3.6.2.0-1.mga5
+ Revision: 655268
- version 3.6.2.0

* Sun May 25 2014 alexl <alexl> 3.5.1.0-1.mga5
+ Revision: 626490
- version 3.5.1.0
- fixed build with qt4.8.6

* Thu Apr 17 2014 alexl <alexl> 3.4.7.1-1.mga5
+ Revision: 615465
- imported package qcad

